Utilities
========

Configuration Parser  
-------------------
.. automodule:: figaroh.utils.config_parser
   :members:
   :undoc-members:
   :show-inheritance:

Cubic Spline
-----------
.. automodule:: figaroh.utils.cubic_spline
   :members:
   :undoc-members:
   :show-inheritance:

Results Manager
--------------
.. automodule:: figaroh.utils.results_manager
   :members:
   :undoc-members:
   :show-inheritance:

Error Handling
--------------
.. automodule:: figaroh.utils.error_handling
   :members:
   :undoc-members:
   :show-inheritance:
